Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1587)

Unified Diff: runtime/vm/cpu_arm.cc

Issue 497893002: Adds recognition of the model string for the DGBox. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/cpu_arm.cc
===================================================================
--- runtime/vm/cpu_arm.cc (revision 39504)
+++ runtime/vm/cpu_arm.cc (working copy)
@@ -84,7 +84,7 @@
vfp_supported_ = CpuInfo::FieldContains(kCpuInfoFeatures, "vfp") &&
FLAG_use_vfp;
// Check for ARMv5, ARMv6 or ARMv7. It can be in either the Processor or
// Model information fields.
if (CpuInfo::FieldContains(kCpuInfoProcessor, "ARM926EJ-S") ||
CpuInfo::FieldContains(kCpuInfoModel, "ARM926EJ-S")) {
@@ -94,6 +94,13 @@
// 12 bytes depending on the implementation. On the Mindstorm EV3 it is 12
// bytes.
store_pc_read_offset_ = 12;
+ } else if (CpuInfo::FieldContains(kCpuInfoProcessor, "Feroceon 88FR131") ||
+ CpuInfo::FieldContains(kCpuInfoModel, "Feroceon 88FR131")) {
+ // This is for the DGBox. For the time-being, assume it is similar to the
+ // Lego Mindstorm.
+ arm_version_ = ARMv5TE;
+ // TODO(zra): Verify with DGLogik that this is correct.
+ store_pc_read_offset_ = 12;
} else if (CpuInfo::FieldContains(kCpuInfoProcessor, "ARMv6") ||
CpuInfo::FieldContains(kCpuInfoModel, "ARMv6")) {
// Raspberry Pi, etc.
@@ -84,7 +84,7 @@
vfp_supported_ = CpuInfo::FieldContains(kCpuInfoFeatures, "vfp") &&
FLAG_use_vfp;
- // Check for ARMv5, ARMv6 or ARMv7. It can be in either the Processor or
+ // Check for ARMv5TE, ARMv6 or ARMv7. It can be in either the Processor or
// Model information fields.
if (CpuInfo::FieldContains(kCpuInfoProcessor, "ARM926EJ-S") ||
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698